<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:import href="layout.xsl"/>

<xsl:template name="title">
	<xsl:choose>
		<xsl:when test="data/@action = 'PayList'">Список платежей Yandex.Деньги</xsl:when>
	</xsl:choose>
</xsl:template>


<xsl:template name="head">
<xsl:text disable-output-escaping="yes">
	<![CDATA[    
<script type="text/javascript">
<!--

// процент комиссии, в числовом виде (например, "5"), заполняется ниже в шаблоне
var percent = 0;

window.onload = function()
{
	$('field_sum').onkeyup = function(e)
	{		
		// проверка на то, что див вообще существует и надо куда-либо что-либо писать
		if( $('div_sumtotal') != null )
		{
		$('div_sumtotal').innerHTML = $('field_sum').value * (100-percent) / 100;
		if( $('div_sumtotal').innerHTML == "" ) $('div_sumtotal').innerHTML = "0";
		if( $('div_sumtotal').innerHTML == "NaN" ) $('div_sumtotal').innerHTML = "?";
		}
	};
};

//-->
</script>   
    ]]>
</xsl:text>
</xsl:template>


<xsl:template match="/data">
	<xsl:choose>
		<xsl:when test="@action = 'PayList'">
			<xsl:call-template name="PayList"/>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="PayList">

	<div class="bgMonthAndYearWidget">
		<xsl:attribute name="month"><xsl:value-of select="/data/@month"/></xsl:attribute>
		<xsl:attribute name="year"><xsl:value-of select="/data/@year"/></xsl:attribute>
		<xsl:attribute name="query"><xsl:value-of select="$WEBEXECUTER"/>?action=<xsl:value-of select="/data/@action"/>&amp;module=<xsl:value-of select="/data/@module"/>&amp;mid=<xsl:value-of select="/data/@mid"/></xsl:attribute></div>

	<table border="0" cellspacing="1" class="table800">
		<thead>
  			<tr>
				<td>Транзакция</td>
				<td>Дата/время оплаты</td>
				<td>Кошелёк</td>
				<td>Сумма общая</td>
				<xsl:if test="config/@paymentSumAmount='shop'">
				<td>Сумма на счёт</td>
				</xsl:if>
  			</tr>
 		</thead>
 		<tbody>	 		
  			<xsl:for-each select="ya/transaction">	  				
				<tr>
					<td><xsl:value-of select="@invoiceId"/></td>
					<td><xsl:value-of select="@paymentDateTime"/></td>
					<td><xsl:value-of select="@paymentPayerCode"/></td>						
					<td nowrap="nowrap"><xsl:value-of select="@orderSumAmount"/>&#160;<xsl:value-of select="@orderSumCurrencyPaycash"/></td>
					<xsl:if test="/data/config/@paymentSumAmount='shop'">
					<td nowrap="nowrap"><xsl:value-of select="@shopSumAmount"/>&#160;<xsl:value-of select="@shopSumCurrencyPaycash"/></td>
					</xsl:if>
				</tr>
  			</xsl:for-each>
  			<xsl:if test="count(ya/transaction) = 0">
  				<tr><td colspan="5"><i>Записи не найдены</i></td></tr>
  			</xsl:if>
 		</tbody>
	</table>
 	
 	<br/><br/>
 	<form method="post" action="{config/@url}" id="authForm">
 
		<xsl:if test="config/@shopId"><input type="hidden" name="shopId" value="{config/@shopId}"/></xsl:if>
		<xsl:if test="config/@shopArticleId"><input type="hidden" name="shopArticleId" value="{config/@shopArticleId}"/></xsl:if>
		<xsl:if test="config/@BankId"><input type="hidden" name="BankId" value="{config/@BankId}"/></xsl:if>
		<xsl:if test="config/@scid"><input type="hidden" name="scid" value="{config/@scid}"/></xsl:if>
		<input type="hidden" name="CustomerNumber" value="{config/@CustomerNumber}"/>
		<input type="hidden" name="mid" value="{/data/@mid}"/>
		<xsl:if test="config/@shopSuccessURL"><input type="hidden" name="scid" value="{config/@shopSuccessURL}"/></xsl:if>
		<xsl:if test="config/@shopFailURL"><input type="hidden" name="scid" value="{config/@shopFailURL}"/></xsl:if>
		
		<xsl:choose>
			<xsl:when test="config/paymentTypes/paymentType">
				<select name="paymentType">
					<xsl:for-each select="config/paymentTypes/paymentType">
						<option value="{@paymentType}">
							<xsl:value-of select="@title"/>
						</option>
					</xsl:for-each>
				</select>
			</xsl:when>
			<xsl:otherwise>
				Оплата со счета Яндекс.Денег.
			</xsl:otherwise>
		</xsl:choose>
		
		Сумма: <input type="text" name="Sum" size="7" id="field_sum"/> рублей

		<xsl:call-template name="submit">
			<xsl:with-param name="title" select="'Оплатить'"/>
			<xsl:with-param name="confirm" select="'Совершить покупку через сайт Yandex.Деньги?'"/>
		</xsl:call-template>

		<xsl:if test="config/@paymentSumAmount='shop'">
			Сумма к зачислению: <span id="div_sumtotal">0</span> рублей.
		</xsl:if>
	</form>
	
	<br/><br/>
	
	<xsl:if test="config/@paymentSumAmount='shop'">
		Внимание! На счёт будет зачислена не вся сумма, а введённая сумма за вычетом комиссии Yandex.
		Комиссия в данный момент составляет <xsl:value-of select="config/@paymentSumPercent"/>%
	</xsl:if>
	
	<xsl:if test="config/@paymentSumAmount='order'">
		На счёт будет зачислена вся введённая сумма, комиссия Yandex не взимается.
	</xsl:if>
	
	<!-- заполняем percent=; -->
	<xsl:text disable-output-escaping="yes">
		<![CDATA[
<script type="text/javascript">
<!--
    	]]>
    </xsl:text>
percent=<xsl:value-of select="config/@paymentSumPercent"/>;
	<xsl:text disable-output-escaping="yes">
		<![CDATA[
//-->
</script>   
    	]]>
	</xsl:text>

</xsl:template>

</xsl:stylesheet>